//THIS FUNCTION WILL CREATE A CLOCK LIKE DISPLAY OF THE INPUT DATA


function clockDisplay(hh_begin, mm_begin, ss_begin, duration, saveAsImg, outDir, fname);

    // hh_begin = start position of hours pointer
    // mm_begin = start position of minutes pointer
    // ss_begin = start position of seconds pointer
    // duration = total time in seconds
    // saveAsImg = status nr if display shall be saved
    // outDir = path to output directory
    // fname = basename of image
    
    // check saveDir
    if saveAsImg == 1
        SaveDir = outDir + '\' + fname
        [status, msg] = mkdir(SaveDir)
        if(status < 1)
            disp(msg)
            return
        end
        frameNr = 0;
    end 
    
    
    
    // define the clock circle
    clock_center = [0 0];
    clock_size   = 1
    
    // check hh > 12
    if hh_begin > 12 then
        hh_begin = hh_begin - 12;
    end
   
    // define the hour needle here
    hh_needle_style        = 1;
    hh_needle_thickness    = 3;
    hh_needle_length       = 0.5; 
    
    // define the minutes needle here
    mm_needle_style        = 1;
    mm_needle_thickness    = 2;
    mm_needle_length       = 0.9; 
    
    // define the seconds needle here
    ss_needle_style        = 1;
    ss_needle_thickness    = 1;
    ss_needle_length       = 0.8; 
    ss_needle_step         = 1

    // create a new figure and delete all the menues and the toolbox                
    fignr = 1000;       // use big numbers, so normal figures won't be affected

    f = figure(fignr);
    delmenu(fignr,'Datei');
    delmenu(fignr,'Zusatzprogramme');
    delmenu(fignr,'Editieren');
    delmenu(fignr,'?');
    toolbar(fignr,'off');

    // define the display settings here
    f.background = 8;
    f.figure_size = [300;300];
    f.figure_name = 'clock';
    f.figure_position = [200;300];

    display_color = 1;
    drawlater();
    // define a symmetric box, so that arc is a circle and not an ellipse
    rect=[-1,-1,1,1];
    plot2d(0,0,0,rect=rect,frameflag=3,axesflag=5); 
    
    // draw a full circle
    xset("color",display_color);
    xarc(-1,1,2,2,0,360*64);                           
    
    // plot a center point
    plot(0,0,'obk');    
    // set the axis
    axisBounds = 1.3
    a = gca();
    a.visible = "on";
    a.box = "off";
    a.data_bounds = [-axisBounds,-axisBounds;axisBounds,axisBounds];
    a.axes_bounds = [0,0,1,1];
    a.margins = [0.0,0.0,0.0,0.0];
    a.axes_reverse = ["on","off","off"];   

    
    // plot the minutes needle
    hh_start_x = clock_center(1);
    hh_start_y = clock_center(2);
    hh_end_x = hh_needle_length * cos(0);
    hh_end_y = hh_needle_length * sin(0);
    
    // plot the minutes needle
    mm_start_x = clock_center(1);
    mm_start_y = clock_center(2);
    mm_end_x = mm_needle_length * cos(0);
    mm_end_y = mm_needle_length * sin(0);
    
    // plot the seconds needle
    ss_start_x = clock_center(1);
    ss_start_y = clock_center(2);
    ss_end_x = ss_needle_length * cos(0);
    ss_end_y = ss_needle_length * sin(0);
    
    // new children will be placed at the top...
    plot([hh_start_x,hh_end_x],[hh_start_y,hh_end_y],'-bk')
    p_hh = a.children(1).children;
    p_hh.thickness = hh_needle_thickness
    
//    plot([hh_start_x,hh_end_x],[hh_start_y,hh_end_y],'-bk')
//    p_hh2 = a.children(1).children;
//    p_hh2.thickness = hh_needle_thickness
//    
//    plot([hh_start_x,hh_end_x],[hh_start_y,hh_end_y],'-bk')
//    p_hh3 = a.children(1).children;
//    p_hh3.thickness = hh_needle_thickness
//    
//    plot([hh_start_x,hh_end_x],[hh_start_y,hh_end_y],'-bk')
//    p_hh4 = a.children(1).children;
//    p_hh4.thickness = hh_needle_thickness
//    
//    plot([hh_start_x,hh_end_x],[hh_start_y,hh_end_y],'-bk')
//    p_hh5 = a.children(1).children;
//    p_hh5.thickness = hh_needle_thickness
    
    // new children will be placed at the top...
    plot([mm_start_x,mm_end_x],[mm_start_y,mm_end_y],'-bk')
    p_mm = a.children(1).children;
    p_mm.thickness = mm_needle_thickness
    
    // new children will be placed at the top...
    plot([ss_start_x,ss_end_x],[ss_start_y,ss_end_y],'-bk')
    p_ss = a.children(1).children;
    p_ss.thickness = ss_needle_thickness
   
    // 360° = 2*pi [rad]
    //  1° =  x    => x  = 1° * 2*pi / 360 
    ss_angleStep = 2 * %pi / 60
    
   
    
    // for the numbers...note, that we switched X-Y, to have a clockwiose rotation
    // xstring(x,y,str,[angle,[box]])
    nr_fontSize = 2;
    xstring(1.05,-0.15,'12')
    a.children(1).font_size = nr_fontSize
    xstring(-0.13,1.08,'3')
    a.children(1).font_size = nr_fontSize
    xstring(-1.32,-0.08,'6')
    a.children(1).font_size = nr_fontSize
    xstring(-0.13,-1.25,'9')
    a.children(1).font_size = nr_fontSize
    
    // plot clock scale
    // the clock shall get points for each minute as a scale
    // hence: 60 points
    for i = 1:60
        point_angle = i * 1/360 * 12*%pi 
        point_end_x = 1 *  cos(point_angle)
        point_end_y = 1 *  sin(point_angle)
        
        plot(point_end_x, point_end_y,'obk')
        a.children(1).children.mark_background = 8;
        a.children(1).children.mark_size = 4
    end
    // the clock shall get points for each hour as a scale
    // hence: 12 points
    for i = 1:12
        point_angle = i * 5/360 * 12*%pi 
        point_end_x = 1 *  cos(point_angle)
        point_end_y = 1 *  sin(point_angle)
        
        plot(point_end_x, point_end_y,'obk')
        a.children(1).children.mark_background = 1;
        
    end
    
     // we ned to se4t the axis OFF afte plotting the last entity
    a.axes_visible = ["off","off","off"];
    a.rotation_angles = [0,0]
    drawnow();
    
    begin = hh_begin *60*60 + mm_begin * 60 + ss_begin
    
    hh_pointer_deviation = 0.3
    
    
    
    for i = begin:begin+duration
        
        ss_angle = (i) * ss_needle_step * ss_angleStep
        mm_angle = ss_angle / 60
        hh_angle = mm_angle / 12
        
        ss_start_x = ss_needle_length*0.05 * cos(ss_angle);
        ss_start_y = ss_needle_length*0.05 * sin(ss_angle);
        ss_end_x = ss_needle_length * cos(ss_angle);
        ss_end_y = ss_needle_length * sin(ss_angle);
        
        mm_start_x = mm_needle_length*0.05 * cos(mm_angle);
        mm_start_y = mm_needle_length*0.05 * sin(mm_angle);
        mm_end_x = mm_needle_length * cos(mm_angle);
        mm_end_y = mm_needle_length * sin(mm_angle);
        
        hh_start_x = hh_needle_length*0.08 * cos(hh_angle);
        hh_start_y = hh_needle_length*0.08 * sin(hh_angle);
        hh_end_x = hh_needle_length * cos(hh_angle);
        hh_end_y = hh_needle_length * sin(hh_angle);
        
        p_ss.data = [ss_start_x,ss_start_y; ss_end_x,ss_end_y]
        p_mm.data = [mm_start_x,mm_start_y; mm_end_x,mm_end_y]
        p_hh.data = [hh_start_x,hh_start_y; hh_end_x,hh_end_y]
        
        if saveAsImg == 1
            
            // make filename for each frame
            frameName = msprintf("%s_%05d.png",fname,frameNr)
    
            xs2png(fignr, SaveDir +'\'+ frameName)
            
            frameNr = frameNr + 1;
        
        end       
        
    end
    
endfunction;


