// this function creates a thermometer like display

function thermometer(temp, unit, savePlot, cmap)

// it takes as input
// - temperature values as numbers (doubles)
// - the unit of these values as a single string
// - an status value [0 or 1] to decide if the displayed image shall be saved as single png-files
//   with that one could afterwards create a movie from the single images
//   Without installing additional toolboxes it is not possible to create a movie by pure Scilab
// - cmap is the color map

    if savePlot == 1  then
        boxTitle = "Please select a directory for storing the single images.."
        outDir = pwd()
        fmask = '.png'
        [fName,fPathName,fIndx]=uiputfile(fmask,outDir,boxTitle)
        
        if fIndx == 0       // abort or chancelling saving 
            disp('Did not save thermometer images.')
            savePlot = 0    // do not save images from thermometer-plot
        end
    end

    minT = min(temp)
    maxT = max(temp)

    // build the thermometer image
    imgWidth = 50
    imgHeight = 200;
    Mask = zeros(imgHeight,imgWidth)
    x1 = imgWidth/2 - 1;
    x2 = imgWidth/2 + 1;
    y_bottom = 15
    y_top    = imgHeight - 15

    // extend thermometer range overr the tmin/tmax from the temp-input
    t_extend = 10
    t_min = floor(min(temp))- t_extend
    t_max = ceil(max(temp)) + t_extend
    y_max = y_top
    y_min = y_bottom

    y_range = y_max - y_min
    t_range = t_max - t_min

    //build the scale
    scale_steps = 10
    y_scale = y_range / scale_steps 
    t_scale = t_range / scale_steps

    for i = 0:scale_steps
        scale_y_pos(i+1) = y_min + y_scale * (i) - 5
        scale_t_val(i+1) = t_min + t_scale * (i)
    end

    Mask(y_bottom:y_top,x1:x2) = 256; 

    f = figure(1000);
    f.toolbar_visible = "off"
    f.menubar_visible = "off"
    f.infobar_visible = "off"
    f.figure_name = ""
    f.axes_size = [imgWidth,imgHeight+100]
    f.background = 100;
    f.color_map = cmap;
    Matplot(Mask);
    a = gca();
    e = gce();
    //a.data_bounds = [x1-10,-10;x2+10,y_top+10]
    a.tight_limits = ["on","on","off"];
    a.margins = [0,0,0,0]
    a.axes_visible = ["off","off","off"]

    // draw the unit
    xstring(5,y_top-8,string(unit),0,0)
    a.children(1).font_foreground = 200;
    a.children(1).font_size = 3;

    // draw the scale
    for(i =1:scale_steps+1)
        xstring(x2+5,scale_y_pos(i),string(round(scale_t_val(i))),0,0)
        a.children(1).font_foreground = 200;
    end

    // build the "bubble at the bottom"
    rC = 8
    xfarc(imgWidth/2-rC/2, y_bottom+1,rC,rC,1,360*64)
    e_arc = a.children(1)
    e_arc.background = 255

    n_temps = max(size(temp))
    for i = 1:n_temps
        t_act = temp(i);
        y_act = (t_max - t_act) / (t_max - t_min) * (y_max - y_min)
        px_act = (t_max - t_act) / (t_max - t_min) * 256 
        Mask(y_bottom:y_top,x1:x2) = px_act
        Mask(y_min:y_top-y_act,x1:x2) = 256 
        e.data = Mask;
        e_arc.background = px_act
        
        if savePlot == 1
            outfName = msprintf("%s_%05d.png",fName,i)
            xs2png(f.figure_id,fPathName+'\'+outfName)
        end
        
    end
    if(savePlot == 1)
        close(f)
    end
endfunction
